==> huaweicloudsdkservicestage-3.1.42-py2.py3-none-any.whl: huaweicloudsdkservicestage/v3/model/application_config_modify_configuration.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ApplicationConfigModifyConfiguration:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'env': 'list[ComponentConfigEnvs]'
    }

    attribute_map = {
        'env': 'env'
    }

    def __init__(self, env=None):
        """ApplicationConfigModifyConfiguration

        The model defined in huaweicloud sdk

        :param env: application environment parameters
        :type env: list[:class:`huaweicloudsdkservicestage.v3.ComponentConfigEnvs`]
        """
        
        

        self._env = None
        self.discriminator = None

        if env is not None:
            self.env = env

    @property
    def env(self):
        """Gets the env of this ApplicationConfigModifyConfiguration.

        application environment parameters

        :return: The env of this ApplicationConfigModifyConfiguration.
        :rtype: list[:class:`huaweicloudsdkservicestage.v3.ComponentConfigEnvs`]
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this ApplicationConfigModifyConfiguration.

        application environment parameters

        :param env: The env of this ApplicationConfigModifyConfiguration.
        :type env: list[:class:`huaweicloudsdkservicestage.v3.ComponentConfigEnvs`]
        """
        self._env = env

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationConfigModifyConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkservicestage-3.1.53-py2.py3-none-any.whl: huaweicloudsdkservicestage/v3/model/application_config_modify_configuration.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ApplicationConfigModifyConfiguration:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'env': 'list[DnsConfigOptions]'
    }

    attribute_map = {
        'env': 'env'
    }

    def __init__(self, env=None):
        """ApplicationConfigModifyConfiguration

        The model defined in huaweicloud sdk

        :param env: application environment parameters
        :type env: list[:class:`huaweicloudsdkservicestage.v3.DnsConfigOptions`]
        """
        
        

        self._env = None
        self.discriminator = None

        if env is not None:
            self.env = env

    @property
    def env(self):
        """Gets the env of this ApplicationConfigModifyConfiguration.

        application environment parameters

        :return: The env of this ApplicationConfigModifyConfiguration.
        :rtype: list[:class:`huaweicloudsdkservicestage.v3.DnsConfigOptions`]
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this ApplicationConfigModifyConfiguration.

        application environment parameters

        :param env: The env of this ApplicationConfigModifyConfiguration.
        :type env: list[:class:`huaweicloudsdkservicestage.v3.DnsConfigOptions`]
        """
        self._env = env

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationConfigModifyConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
